@@ -1,4 +1,4 @@
-package TeX::Hyphen::Pattern 0.103;    # -*- cperl; cperl-indent-level: 4 -*-
+package TeX::Hyphen::Pattern v1.1.1;    # -*- cperl; cperl-indent-level: 4 -*-
 use Moose;
 use 5.014000;
 use utf8;
@@ -203,7 +203,7 @@ patterns for use with TeX::Hyphen.
 
 =head1 VERSION
 
-This is version 0.103. To prevent plugging in of incompatible modules the
+This is version v1.1.1. To prevent plugging in of incompatible modules the
 version of the pluggable modules must be the same as this module.
 
 =head1 SYNOPSIS
@@ -303,7 +303,7 @@ L<TeX::Hyphen|TeX::Hyphen>.  Versions up to and including 0.140 don't support
 C<utf8>, so patterns using C<utf8> that are included in this package have a
 version number 0.00 to ignore them. Should you patch
 L<TeX::Hyphen|TeX::Hyphen> yourself by inserting a C<binmode FILE, ":utf8";>
-you can change those version numbers to 0.103 to include them.
+you can change those version numbers to v1.1.1 to include them.
 
 =back
 
@@ -356,7 +356,7 @@ Roland van Ipenburg, E<lt>ipenburg@xs4all.nlE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2018 by Roland van Ipenburg
+Copyright 2019 by Roland van Ipenburg
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
